@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------
-#     Copyright (C) 2012-2015  Serge Iovleff, University Lille 1, Inria
+#     Copyright (C) 2012-2016  Serge Iovleff, University Lille 1, Inria
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as
@@ -105,7 +105,7 @@ clusterStrategy <- function( nbTry =1
 
 #' @description
 #' \code{clusterSemiSEMStrategy()} create an instance of [\code{\linkS4class{ClusterStrategy}}]
-#' for users with many missing values.
+#' for users with many missing values uning a semiSem algorithm.
 #' @examples
 #'    clusterSemiSEMStrategy()
 #'
@@ -123,6 +123,26 @@ clusterSemiSEMStrategy <- function()
   new("ClusterStrategy", nbTry= 2, nbShortRun= 5, initMethod= initMethod, shortAlgo= shortAlgo, longAlgo= longAlgo);
 }
 
+#' @description
+#' \code{clusterSEMStrategy()} create an instance of [\code{\linkS4class{ClusterStrategy}}]
+#' for users with many missing values using a SEM algorithm.
+#' @examples
+#'    clusterSEMStrategy()
+#'
+#' @rdname clusterStrategy
+#' @export
+clusterSEMStrategy <- function()
+{
+  # create init
+  initMethod = clusterInit("class", 5, "SEM", 20, 0);
+  # create shortAlgo
+  shortAlgo = clusterAlgo("SEM", 50, 0);
+  # create longAlgo
+  longAlgo = clusterAlgo("SEM", 400, 0);
+  # create strategy
+  new("ClusterStrategy", nbTry= 2, nbShortRun= 5, initMethod= initMethod, shortAlgo= shortAlgo, longAlgo= longAlgo);
+}
+
 #' @description
 #' \code{clusterFastStrategy()} create an instance of [\code{\linkS4class{ClusterStrategy}}] for impatient user.
 #' @examples
@@ -135,7 +155,7 @@ clusterFastStrategy <- function()
   # create init
   initMethod = clusterInit("class", 3, "EM", 5, 0.01);
   # create shortAlgo
-  shortAlgo = clusterAlgo("CEM", 10, 0.001);
+  shortAlgo = clusterAlgo("EM", 10, 0.001);
   # create longAlgo
   longAlgo = clusterAlgo("EM", 100, 1e-07);
   # create strategy
