@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------
-#     Copyright (C) 2012-2014  Inria
+#     Copyright (C) 2012-2016  Inria
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as
@@ -25,7 +25,7 @@
 #' @include ClusterStrategy.R
 NULL
 
-#' Interface base Class [\code{\linkS4class{IClusterModelBase}}] for Cluster models.
+#' Interface base Class [\code{\linkS4class{IClusterModel}}] for Cluster models.
 #'
 #' This class encapsulate the common parameters of all the Cluster models.
 #'
@@ -36,7 +36,7 @@ NULL
 #'    \quad {x} \in J.
 #' }
 #' where h can be either a pdf, a discrete probability, (homogeneous case)
-#' or a product of arbitrary pdf and discrete probabilities (heterogeneous case).
+#' or a product of arbitrary pdf and discrete probabilities (mixed data case).
 #'
 #' @slot nbSample  Integer with the number of samples of the model.
 #' @slot nbCluster Integer with the number of cluster of the model.
@@ -52,16 +52,16 @@ NULL
 #' estimation process of the mixture. Default is clusterStrategy().
 #'
 #' @examples
-#'   getSlots("IClusterModelBase")
+#'   getSlots("IClusterModel")
 #'
 #' @author Serge Iovleff
 #'
-#' @name IClusterModelBase
+#' @name IClusterModel
 #' @rdname ClusterModels-class
-#' @aliases IClusterModelBase-class
-#' @exportClass IClusterModelBase
+#' @aliases IClusterModel-class
+#' @exportClass IClusterModel
 setClass(
-  Class="IClusterModelBase",
+  Class="IClusterModel",
   representation( nbSample = "numeric"
                 , nbCluster = "numeric"
                 , pk = "numeric"
@@ -125,7 +125,7 @@ setClass(
 
 #' Initialize an instance of a MixAll S4 class.
 #'
-#' Initialization method of the [\code{\linkS4class{IClusterModelBase}}] class.
+#' Initialization method of the [\code{\linkS4class{IClusterModel}}] class.
 #' Used internally in the 'MixAll' package.
 #'
 #' @rdname initialize-methods
@@ -133,17 +133,17 @@ setClass(
 #'
 setMethod(
   f="initialize",
-  signature=c("IClusterModelBase"),
-  definition=function(.Object, nbSample=0, nbCluster=0)
+  signature=c("IClusterModel"),
+  definition=function(.Object, nbSample, nbCluster)
   {
     # for nbSample
-    if(missing(nbSample)) { stop("nbSample is mandatory in IClusterModelBase.")}
+    if(missing(nbSample)) { stop("nbSample is mandatory in IClusterModel.")}
     .Object@nbSample <- nbSample;
     # for nbCluster
-    if(missing(nbCluster)) { stop("nbCluster is mandatory in IClusterModelBase.")}
+    if(missing(nbCluster)) { stop("nbCluster is mandatory in IClusterModel.")}
     .Object@nbCluster<-nbCluster
     # resize
-    .Object@pk   <- rep(1/.Object@nbCluster, nbCluster)
+    .Object@pk   <- rep(1/nbCluster, nbCluster)
     .Object@tik  <- matrix(1/nbCluster, nbSample, nbCluster)
     .Object@lnFi <- rep(0, nbSample)
     .Object@zi   <- as.integer(rep(1, nbSample))
@@ -160,11 +160,11 @@ setMethod(
 )
 
 #' @rdname print-methods
-#' @aliases print print,IClusterModelBase-method
+#' @aliases print print,IClusterModel-method
 #'
 setMethod(
   f="print",
-  signature=c("IClusterModelBase"),
+  signature=c("IClusterModel"),
   function(x,...)
   {
     cat("* nbSample       = ", x@nbSample, "\n")
@@ -178,10 +178,10 @@ setMethod(
 )
 
 #' @rdname show-methods
-#' @aliases show show,IClusterModelBase-method
+#' @aliases show show,IClusterModel-method
 setMethod(
   f="show",
-  signature=c("IClusterModelBase"),
+  signature=c("IClusterModel"),
   function(object)
   {
     cat("* nbSample       = ", object@nbSample, "\n")
@@ -193,10 +193,10 @@ setMethod(
 )
 
 #' @rdname summary-methods
-#' @aliases summary summary,IClusterModelBase-method
+#' @aliases summary summary,IClusterModel-method
 setMethod(
   f="summary",
-  signature=c("IClusterModelBase"),
+  signature=c("IClusterModel"),
   function(object,...)
   {
     cat("* nbSample       = ", object@nbSample, "\n")
@@ -228,7 +228,10 @@ setMethod(
 #'
 setClass(
   Class="IClusterComponent",
-  representation( data = "matrix", missing = "matrix", modelName = "character", "VIRTUAL"),
+  representation( data = "matrix"
+                , missing = "matrix"
+                , modelName = "character"
+                , "VIRTUAL"),
   validity=function(object)
   {
 # called too soon when Component is part of an other S4 class
@@ -301,3 +304,74 @@ setMethod(
   function(object, ...)
   { cat("* model name     =",object@modelName,"\n");}
 )
+## 
+## #-----------------------------------------------------------------------
+## #' Interface base Class [\code{\linkS4class{IClusterPredict}}] for predictors
+## #' using cluster models.
+## #'
+## #' This class encapsulate the common parameters of all the predictors using a
+## #' cluster model.
+## #'
+## #'
+## #' @slot tik  Matrix of size \eqn{n \times K} with the predicted posterior
+## #' probabilities of the ith individual to belong to kth cluster.
+## #' @slot lnFi Vector of size n with the predicted log-likelihood of the ith
+## #' individuals.
+## #' @slot zi   Vector of integer of size n with the predicted class label of
+## #' the individuals.
+## #'
+## #' @examples
+## #'   getSlots("IClusterPredict")
+## #'
+## #' @author Serge Iovleff
+## #'
+## #' @name IClusterPredict
+## #' @rdname IClusterPredict-class
+## #' @aliases IClusterPredict-class
+## #' @exportClass IClusterPredict
+## #'
+## setClass(
+##     Class="IClusterPredict",
+##     representation( nbSample = "numeric"
+##                   , nbCluster = "numeric"
+##                   , tik = "matrix"
+##                   , lnFi = "numeric"
+##                   , zi = "integer"
+##                   , "VIRTUAL"
+##                   ),
+##     validity=function(object)
+##     {
+##       return(TRUE)
+##     }
+## )
+## 
+## #' Initialize an instance of a MixAll S4 class.
+## #'
+## #' Initialization method of the [\code{\linkS4class{IClusterPredict}}] class.
+## #' Used internally in the 'MixAll' package.
+## #'
+## #' @rdname initialize-methods
+## #' @keywords internal
+## #'
+## setMethod(
+##     f="initialize",
+##     signature=c("IClusterPredict"),
+##     definition=function(.Object, nbSample, nbCluster)
+##     {
+##       # for nbSample
+##       if(missing(nbSample)) { stop("nbSample is mandatory in IClusterPredict.")}
+##       .Object@nbSample <- nbSample;
+##       # for nbCluster
+##       if(missing(nbCluster)) { stop("nbCluster is mandatory in IClusterPredict.")}
+##       .Object@nbCluster<-nbCluster
+##       # resize
+##       .Object@pk   <- rep(1/nbCluster, nbCluster)
+##       .Object@tik  <- matrix(1/nbCluster, nbSample, nbCluster)
+##       .Object@lnFi <- rep(0, nbSample)
+##       .Object@zi   <- as.integer(rep(1, nbSample))
+##       # validObject(.Object) will be called at the end of the initialization process
+##       # in the derived classes
+##       return(.Object)
+##     }
+## )
+## 
